module.exports = defineTest({
	description:
		'take actual parameters into account when determining side-effects of calls to functions'
});
